function conversion ( chaine ) {
	/* Cette fonction va nous permette de convertir
	une chaîne de caractère du type "1h 1 min 2s"
	en un nombre de secondes comparable à ce que nous fournit AE */

	chaine = chaine || '';

	// on récupère une liste contenant soit rien soit le nombre d'heure(s)
	// la partie qui ressemble à une insulte
	// en l'occurence /\d*(?= *h)/
	// est une expression régulière
	var h = chaine.match(/\d*(?= *h)/);
	// si la liste retournée n'est pas un null, une valeur a été trouvée
	// la liste contient un élément, on le récupère
	// et on la convertit du type string vers number
	// sinon la liste est un null (pas de valeur trouvée,
	// alors on utilise le nombre 0 à la place
	h = h !== null ? parseInt( h[0] ) : 0;

	// idem pour les minutes
	var m = chaine.match(/\d*(?= *min)/);
	m = m !== null ? parseInt( m[0] ) : 0;

	// idem pour les secondes
	var s = chaine.match(/\d*(?= *s)/);
	s = s !== null ? parseInt( s[0] ) : 0;

	// on retourne
	// le nombre d'heure * nombre de secondes dans une heure
	// plus le nombre de minutes * nombre de secondes dans une minutes
	// plus le nombre de secondes
	return h * 3600 + m * 60 + s;
}

function obtenir_chemin_absolu ( chemin_relatif ) {
	/* permet d'obtenir le chemin absolu d'un fichier sur la base
	d'un chemin relatif et du chemin du répertoire de sauvegarde */

	// si le projet n'est pas sauvegardé ça ne marchera pas
	if ( app.project.file == null ) {
		alert( 'Ce script ne peux fonctionner qu\'une fois votre projet sauvegardé. Veuillez sauvegarder votre projet.' )

		// on arrête tout et on renvoie undefined
		return;
	}
	// si le projet est bien sauvegardé
	return app.project.file.absoluteURI.replace( app.project.file.name, chemin_relatif );
}

function parser_TSV ( chemin ) {
	/* permet de transformer un fichier TSV en tableau */

	// on créé un tableau
	var sortie = [];

	// on essaie
	try {

		// de créer un nouveau fichier
		// basé sur cet chemin
		var fichier = new File ( chemin );
		// de l'ouvrir
		fichier.open("r");
		// tant qu'on est pas arrivé à la fin du fichier
		while ( !fichier.eof ){
			// on ajoute les lignes à la sortie en « splittant »
			// on niveau des tabulations
			sortie.push( fichier.readln().split('	') );
		}
		// on ferme le fichier
		fichier.close();
	// si erreur
	} catch ( erreur ) {
		// on affiche l'erreur
		alert( erreur );
		// on renvoie le tableau en l'état
	} finally {
	// on renvoie la sortie;
	return sortie;
	}
}

function ajouter_null_a ( item, nom ) {
	/* ajoute un null à l'objet donné */
	var nul = item.layers.addNull();
	// définit le nom du null
	nul.source.name = nom;
	// retourne une référence vers le null créé
	return nul;
}


function main () {
	/* programme principal */

	// je récupère les données structurées
	// issues de la lecture du fichier 'tracklist.tsv'
	var data = parser_TSV( obtenir_chemin_absolu( 'tracklist.tsv' ) );

	// si je n'ai aucun Item sélectionné
	if ( app.project.activeItem === null ) {
		// je renvoie l'information
		alert( "aucune composition élément sélectionné" );
		// je ne vais pas plus loin
		return;
	// si l'Item n'est pas une composition (CompItem)
	} else if ( !app.project.activeItem instanceof CompItem ) {
		// je renvoie l'information
		alert( "la sélection n'est pas une composition" );
		// je ne vais pas plus loin
		return;
	}
	// si j'ai une composition :
	// j'ajoute un nul dont je récupère la référence
	var nul = ajouter_null_a( app.project.activeItem, 'track_id' );
	// je lui ajoute un effect « paramètre pour expression / glissière »
	var effet = nul.property("Effects").addProperty("Paramètre glissière");
	// je récupère la référence vers le curseur
	var curseur = effet.property("Curseur");

	// pour chaque ligne de donnée
	for (var i = 0; i < data.length; i++) {
		// je rajoute une image clé avec une valeur
		// sur mon curseur
		curseur.setValueAtTime( conversion( data[i][0] ) , i-1 );
	}
}


main();


/*
for (var i = 0; i < data.length; i++) {
	$.writeln(conversion( data[i][0] ));
}
*/


function tester ( objet ) {
	$.writeln( "=========" );
	for (var key in objet) {
    if (objet.hasOwnProperty(key)) {
        /* useful code here */
				$.writeln( key );
    }
	}
	$.writeln( "=========" );
}
